<?php
/*
  Plugin Name: Woo Extra Features 
  Version: 1.0.1
  Description: Features manager add-on for WooCommerce. Display extra product features in new product tab.
  Plugin URI: https://maxstore.co.il	
  Author: Maxstore Cloud Platform
  Author URI: https://maxstore.co.il
 */

// Check if class is already exists with the same name

if (!class_exists('Infi_Product_Features')) {

    /**

     * Main Class

     *

     * @class Infi_Product_Features

     * @version	1.0

     * @since 1.0

     */
    class Infi_Product_Features {

        /**

         * @class Infi_Product_Features

         * @role - Constructor

         * @version	1.0

         * @since 1.0

         */
        function __construct() {
			
			//WMPL
			/**
			 * register strings for translation
			 */
			if (function_exists ( 'icl_register_string' )){
				icl_register_string('woofeatures', 'Features Tab Title', 'Product Features');
			}
			//WMPL
			
			add_action('init', array($this, 'load_translation'));

            // Create admin menu for options page

            add_action('admin_menu', array($this, 'features_manager_menu'));

			
			// check woocommerce installed
			
			add_action( 'admin_notices', array($this, 'feature_woo_check_admin_notice'));

            // Register AJAX action for adding new features

            add_action('wp_ajax_infi_new_feature', array($this, 'add_new_feature'));



            // Register AJAX action for updating existing feature

            add_action('wp_ajax_infi_update_feature', array($this, 'update_feature'));



            // Register AJAX action for deleting existing feature

            add_action('wp_ajax_infi_delete_feature', array($this, 'delete_feature'));

            // Register AJAX action for clone existing feature

            add_action('wp_ajax_infi_clone_feature', array($this, 'clone_feature'));

            // Register AJAX action for update feature tab title

            add_action('wp_ajax_infi_update_ft', array($this, 'update_title'));



            // Register AJAX action for deleting existing feature

            add_action('wp_ajax_infi_update_order', array($this, 'update_order'));



            // Enqueue scripts on frontend

            add_action('wp_enqueue_scripts', array($this, 'scripts_on_front'));



            // Enqueue scripts on frontend

            add_action('admin_enqueue_scripts', array($this, 'scripts_on_admin'));



            // Register "Product Features" tab on Single Product page

            add_filter('woocommerce_product_tabs', array($this, 'woo_new_product_features_tab'));
        }

		/**

         * @class Infi_Product_Features

         * @role - Woocommerce check

         * @version	1.0

         * @since 1.0

         */

		function feature_woo_check_admin_notice()
		{
			$active_plugins = (array) get_option( 'active_plugins', array() );

			if ( is_multisite() ) {
				$active_plugins = array_merge( $active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
			}
	
			if(in_array( 'woocommerce/woocommerce.php', $active_plugins ) || array_key_exists( 'woocommerce/woocommerce.php', $active_plugins ))
			{
				return true;
			}
			else
			{
		?>
			<div class="error">
				<?php _e( '<p>Product Feature Tab plugin requires active <a href="https://wordpress.org/plugins/woocommerce/" target="_blank">WOOCOMMERCE plugin</a></p>', 'woofeatures' ); ?>
			</div>
		<?php
			}
		}

        /**

         * @class Infi_Product_Features

         * @role - WPML support

         * @version	1.0

         * @since 1.0

         */
        public function load_translation() {

            // localization
            load_plugin_textdomain('woofeatures', false, dirname(plugin_basename(__FILE__)) . '/languages');
        }

        /**

         * @class Infi_Product_Features

         * @role - Register admin sub-menu under products post type

         * @version	1.0

         * @since 1.0

         */
        function features_manager_menu() {

            // Register sub-menu under product post type menu and get the url into the variable $page

            $page = add_submenu_page(
                    "edit.php?post_type=product", __("Product Features Manager", "woofeatures"), __("Features Manager", "woofeatures"), "administrator", "product_features", array($this, 'features_manager_dashboard')
            );

            // Print styles on only options page

            add_action('admin_print_styles-' . $page, array($this, 'admin_styles'));



            // Print scripts on only options page

            add_action('admin_print_scripts-' . $page, array($this, 'admin_scripts'));
        }

        /**

         * @class Infi_Product_Features

         * @role - Prints styles on plugins options pages only

         * @version	1.0

         * @since 1.0

         */
        function admin_styles() {

            wp_enqueue_style('features-dashboard', plugins_url('/css/admin.css', __FILE__));
        }

        /**

         * @class Infi_Product_Features

         * @role - Prints styles on plugins options pages only

         * @version	1.0

         * @since 1.0

         */
        function admin_scripts() {

            wp_enqueue_script('features-admin-script', plugins_url('/js/admin.js', __FILE__), '1.0', array());

            wp_enqueue_script('features-admin-media', plugins_url('/js/admin-media.js', __FILE__), '1.0', array());

            wp_enqueue_script('jquery-ui-sortable');
        }

        /**

         * @class Infi_Product_Features

         * @role - enqueue styles and scripts on frontend

         * @version	1.0

         * @since 1.0

         */
        function scripts_on_admin() {

            wp_enqueue_style('features-meta', plugins_url('/css/admin-meta.css', __FILE__));
            wp_enqueue_style('icon-styles', plugins_url('/css/font-awesome.min.css', __FILE__), false, '4.2.0');

            wp_register_script('reveal_js', plugins_url('js/jquery.reveal.js', __FILE__), array('jquery'), false, '1.0');
            wp_enqueue_script('reveal_js');
            wp_register_style('reveal_css', plugins_url('css/reveal.css', __FILE__), false, '1.0');
            wp_enqueue_style('reveal_css');
			
			wp_enqueue_style( 'wp-color-picker' );
            wp_enqueue_script( 'product-features-tab', plugins_url('js/product-features-tab.js', __FILE__ ), array( 'wp-color-picker' ), false, true );
        }

        /**

         * @class Infi_Product_Features

         * @role - enqueue styles and scripts on frontend

         * @version	1.0

         * @since 1.0

         */
        function scripts_on_front() {

            wp_enqueue_style('features-acrd', plugins_url('/css/style.css', __FILE__));
            wp_enqueue_style('icon-styles', plugins_url('/css/font-awesome.min.css', __FILE__), false, '4.2.0');
            if (is_rtl()) {
                wp_enqueue_style('features-acrd-rtl', plugins_url('/css/rtl.css', __FILE__));
            }
        }

        /**

         * @class Infi_Product_Features

         * @role - Add new feature from request by AJAX

         * @AJAX action - 'infi_new_feature'

         * @version	1.0

         * @since 1.0

         */
        function add_new_feature() {

            // Initialize blank variables to prevent "undefined variable" error

            $title = $desc = $err = $key = $icon = '';

            $result = false;

            // validate key

            if (isset($_POST['key']) && $_POST['key'] !== '')
                $key = $_POST['key'];

            // validate icon

            if (isset($_POST['feature_icon_type']) && $_POST['feature_icon_type'] == 'image')
            {
                $icon = $_POST['feature_icon'];                
            }
            else
            {
                $icon = $_POST['font_feature_icon'];
            }            
            
            // validate title

            if (isset($_POST['feature_title']) && $_POST['feature_title'] !== '')

            // if feature_title is not blank, assign its value to $title
                $title = $_POST['feature_title'];

            else

            // If is blank, stop executation with an error
                die(__('<div class="error"><p>Feature title should not be blank</p></div>', 'woofeatures'));

            // validate description

            if (isset($_POST['feature_desc']) && $_POST['feature_desc'] !== '')
                $desc = $_POST['feature_desc'];


            // continue execution for adding the feature to the database

            $feature = array();

            // retrive and store previous features in variable - $prev_features

            $prev_features = get_option('infi_features');



            if (!is_array($prev_features)) {

                $feature[] = array(
                    "icon" => $icon,
                    "feature_icon_type" => $_POST['feature_icon_type'],
					"font_color_code" => $_POST['font_color_code'],
                    "title" => $title,
                    "desc" => $desc,
                );

                $result = update_option('infi_features', $feature);
            } else {

                $prev_features[] = array(
                    "icon" => $icon,
                    "feature_icon_type" => $_POST['feature_icon_type'],
					"font_color_code" => $_POST['font_color_code'],					
                    "title" => $title,
                    "desc" => $desc,
                );

                $result = update_option('infi_features', $prev_features);
            }

            if ($result) {

                $array = get_option('infi_features');

                $order_array = get_option('feature_order');

                end($array);         // move the internal pointer to the end of the array

                $key = key($array);  // fetches the key of the element pointed to by the internal pointer



                $order_array[] = $key;



                update_option('feature_order', $order_array);



                $status = __('added', 'woofeatures');
            } else {

                $status = __('not_added', 'woofeatures');
            }

            // return the result to the ajax call

            echo $status;



            // stop execution to prevent AJAX appending '0' to the generated output

            die();
        }

        /**

         * @class Infi_Product_Features

         * @role - Update existing feature from request by AJAX. Requires feature key

         * @AJAX action - 'infi_update_feature'

         * @since 1.0

         */
        function update_feature() {

            $title = $desc = $err = $key = $icon = '';

            $result = false;

            // validate key

            if (isset($_POST['key']) && $_POST['key'] !== '')
                $key = $_POST['key'];

            // validate icon

            if (isset($_POST['feature_icon_type']) && $_POST['feature_icon_type'] == 'image')
            {
                $icon = $_POST['feature_icon'];                
            }
            else
            {
                $icon = $_POST['font_feature_icon'];
            }            

            // validate title

            if (isset($_POST['feature_title']) && $_POST['feature_title'] !== '')
                $title = $_POST['feature_title'];

            else
                die(__('<div class="error"><p>Feature title should not be blank</p></div>', 'woofeatures'));

            // validate description

            if (isset($_POST['feature_desc']) && $_POST['feature_desc'] !== '')
                $desc = $_POST['feature_desc'];



            // proceed for adding the feature to the database

            $prev_features = get_option('infi_features');

            $prev_features[$key] = array(
                "icon" => $icon,
                "feature_icon_type" => $_POST['feature_icon_type'],
				"font_color_code" => $_POST['font_color_code'],
                "title" => $title,
                "desc" => $desc,
            );

            $result = update_option('infi_features', $prev_features);

            if ($result)
                $status = __('updated', 'woofeatures');

            else
                $status = __('not_updated', 'woofeatures');

            // return the result to the ajax call

            echo $status;



            // stop execution to prevent AJAX appending '0' to the generated output

            die();
        }

        /**

         * @class Infi_Product_Features

         * @role - Delete any existing feature from request by AJAX. Requires feature key

         * @AJAX action - 'infi_delete_feature'

         * @version	1.0

         * @since 1.0

         */
        function delete_feature() {

            // Check if feature key is provided by AJAX

            if (isset($_POST['key'])) {

                // assign the provided feature key to a variable - $key

                $key = $_POST['key'];



                // Get registered features

                $prev_features = get_option('infi_features');



                // Remove the feature of given key from retrieved features array

                unset($prev_features[$key]);

                // Update new array to the database and store the result to the variable - $result

                $result = update_option('infi_features', $prev_features);

                if ($result) {

                    // Remove the feature order of given key from retrieved features array

                    $order_array = get_option('feature_order');
                    unset($order_array[$key]);
                    update_option('feature_order', $order_array);

                    echo('deleted');
                } else {

                    echo('error');
                }
            }



            // stop execution to prevent AJAX appending '0' to the generated output

            die();
        }

        /**

         * @class Infi_Product_Features

         * @role - Clone any existing feature from request by AJAX. Requires feature key

         * @AJAX action - 'infi_clone_feature'

         * @version	1.0

         * @since 1.0

         */
        function clone_feature() {

            // Check if feature key is provided by AJAX

            if (isset($_POST['key'])) {
                // assign the provided feature key to a variable - $key

                $key = $_POST['key'];

                // Get registered features

                $prev_features = get_option('infi_features');

                $prev_features[] = array(
                    "icon" => $prev_features[$key]['icon'],
                    "feature_icon_type" => $prev_features[$key]['feature_icon_type'],
                    "title" => $prev_features[$key]['title'],
					"font_color_code" => $prev_features[$key]['font_color_code'],
                    "desc" => $prev_features[$key]['desc'],
                );

                $result = update_option('infi_features', $prev_features);

                if ($result) {

                    $array = get_option('infi_features');

                    $order_array = get_option('feature_order');

                    end($array);         // move the internal pointer to the end of the array

                    $key = key($array);  // fetches the key of the element pointed to by the internal pointer

                    $order_array[] = $key;

                    update_option('feature_order', $order_array);

                    $status = __('success', 'woofeatures');
                } else {

                    $status = __('not_added', 'woofeatures');
                }
            }

            echo $status;

            // stop execution to prevent AJAX appending '0' to the generated output

            die();
        }

        /**

         * @class Infi_Product_Features

         * @role - Handles update title request

         * @version	1.0

         * @since 1.0

         */
        function update_title() {

            if (isset($_POST['title'])) {

                $update_title = $_POST['title'];
				$tab_order = $_POST['tab_order'];
				
                $title_status = update_option('ft_title', $update_title);
				$order_status = update_option('ft_tab_order', $tab_order);
				
				//WMPL
				/**
				 * register strings for translation
				 */
				if (function_exists ( 'icl_register_string' )){
					icl_register_string('woofeatures', 'Features Tab Title', $update_title);
				}
				//WMPL

                if ($title_status || $order_status)
                    echo 'updated';

                else
                    echo 'error';
            }

            die();
        }

        /**

         * @class Infi_Product_Features

         * @role - Handles update features order request.

         * @version	1.0

         * @since 1.0

         */
        function update_order() {

            if (isset($_POST['feature_order'])) {

                $features_order = $_POST['feature_order'];

                $result = update_option('feature_order', $features_order);

                if ($result) {

                    echo 'updated';
                } else {

                    echo 'error';
                }
            }

            die();
        }

        /**

         * @class Infi_Product_Features

         * @role - Handles dashboard actions. Loads options page interface depending on request.

         * @version	1.0

         * @since 1.0

         */
        function features_manager_dashboard() {

            // Check if action is set

            if (isset($_GET['action'])) {

                // If action is for new feature, load page from 'add-new-feature.php'

                if ($_GET['action'] == 'new_feature')
                    include('add-new-feature.php');

                // If action is for edit feature, load page from 'edit-feature.php'

                elseif ($_GET['action'] == 'edit_feature')
                    include('edit-feature.php');

                // If action is not set, redirect to features manager dashboard
            } else {

                // Load Features manager from 'features-manager-dashboard.php'

                include('features-manager-dashboard.php');
            }
        }

        /**

         * @class Infi_Product_Features

         * @role - Creates "Product Features" tab on single product page view

         * @version	1.0

         * @since 1.0

         */
        function woo_new_product_features_tab($tabs) {



            // Adds the "Product Features" tab

            global $post;

            $post_features = get_post_meta($post->ID, 'woo_product_features', true);

            $title = get_option('ft_title');

            $features_title = get_post_meta($post->ID, 'features_tab_title', true);
			
			if (function_exists ( 'icl_translate' )){
				$title    = icl_translate('woofeatures', 'Features Tab Title', $title);
			}

            if ($features_title == "")
                $features_title = $title;

            if (is_array($post_features)) {

                $tabs['features_tab'] = array(
                    'title' => $features_title,
                    'priority' => get_option('ft_tab_order') != '' ? get_option('ft_tab_order') : 30,
                    'callback' => array($this, 'woo_new_product_features_tab_content')
                );
            }



            return $tabs;
        }

        /**

         * @class Infi_Product_Features

         * @role - Generates product features accordions depending on features selected

         * @version	1.0

         * @since 1.0

         */
        function woo_new_product_features_tab_content() {



            // Get post data

            global $post;



            // Generate unique id for each accordion and store it in a variable - $uid

            $uid = uniqid();



            // Get all features

            $features = get_option('infi_features');



            // Get features order

            $feature_order = get_option('feature_order');



            // Get features selected for the current product being viewed

            $post_features = get_post_meta($post->ID, 'woo_product_features', true);



            //print_r($post_features);



            $new_order = array();

            foreach ($feature_order as $key => $order) {

                foreach ($post_features as $key => $value) {

                    if ($order == $value) {

                        array_push($new_order, $value);
                    }
                }
            }

            //print_r($new_order);
            // Loop through the selected features array and generate accordion for each feature

            foreach ($new_order as $key => $value) {

                if ($key == 0) {
                    $checked = "checked";
                } else {
                    $checked = "";
                }

                // The new tab content

                $html = "\n" . '<section class="ac-container">';

                $html .= "\n\t" . '<div>';

                $html .= "\n\t\t" . '<input id="ac-' . $key . '" name="ac-' . $uid . '" type="radio" ' . $checked . ' />';

				if($feature['feature_icon_type'] == 'image' && $feature['icon'] != '')
				{
					$html .= "\n\t\t" . '<label for="ac-' . $key . '"><img src="' . $features[$value]['icon'] . '" class="feature-tab-icon"/>' . $features[$value]['title'] . '</label>';
				}
				else
				{
					$html .= "\n\t\t" . '<label for="ac-' . $key . '">&nbsp;<i style="color:'.$features[$value]['font_color_code'].'" class="fa fa-lg fa-'.$features[$value]['icon'].'"></i> ' . $features[$value]['title'] . '</label>';
				}                

                $html .= "\n\t\t" . '<article class="ac-small">' . html_entity_decode($features[$value]['desc']) . '</article>';

                $html .= "\n\t" . '</div>';

                $html .= "\n" . '</section>';

                echo $html;
            }
        }

    }

    // end class Infi_Product_Features

    /**

     * Instantiate the class 'Infi_Product_Features'

     */
    new Infi_Product_Features;



    // Register required meta boxes

    require_once('features-meta.php');
    include('functions.php');    
}